
<!-- PROJECT LOGO -->
<br />
<div align="center">
  <a href="https://github.com/rahuldshetty/horde-client">
    <img src="https://raw.githubusercontent.com/rahuldshetty/horde-client/master/images/logo.png" alt="Logo" width="100" height="90">
  </a>

  <h3 align="center">Horde Client
</h3>

  <p align="center">
    Easy-to-use Python Interface for KoboldAI Horde.
    <br />
    <a href="#"><strong>Explore the docs »</strong></a>
    <br />
    <br />
    <a href="#">View Demo</a>
    ·
    <a href="https://github.com/rahuldshetty/horde-client/issues">Report Bug</a>
    ·
    <a href="https://github.com/rahuldshetty/horde-client/issues">Request Feature</a>
  </p>
</div>

<!-- ABOUT THE PROJECT -->
## About The Project

<!-- [![Product Name Screen Shot][product-screenshot]](https://example.com) -->

This project provides Python Client to interact with [KoboldAI Horde](https://horde.koboldai.net) service, which is crowdsourced distributed cluster program that offers Image generation and Text Generation workers.

* Simple & Easy-to-use.
* Support for Text Generation & Image Generation (WIP).
* More Examples! (on the way)

> Note: There is an official Python SDK under development from Haidra-org: https://github.com/Haidra-Org/horde-sdk.

<!-- ROADMAP -->
## Roadmap

- [X] Text Generation Support
- [ ] Image Generation Support
- [ ] Asynchronous Client
- [ ] Readthedocs integration
- [ ] Tests

Missing Something? Raise a [request](https://github.com/rahuldshetty/horde-client/issues) 

<!-- CONTRIBUTING -->
## Contributing

Any contributions you make are **greatly appreciated**.

If you have a suggestion that would make this better, please fork the repo and create a pull request. You can also simply open an issue with the tag "enhancement".
Don't forget to give the project a star! Thanks again!

1. Fork the Project
2. Create your Feature Branch (`git checkout -b feature/AmazingFeature`)
3. Commit your Changes (`git commit -m 'Add some AmazingFeature'`)
4. Push to the Branch (`git push origin feature/AmazingFeature`)
5. Open a Pull Request

